@@ -59,10 +59,13 @@ ORC_SOURCE_TYPE = 'ORC'
 STATA_SOURCE_TYPE = 'STATA'
 SAS_SOURCE_TYPE = 'SAS'
 SPSS_SOURCE_TYPE = 'SPSS'
+JSON_SOURCE_TYPE = 'JSON'
+XML_SOURCE_TYPE = 'XML'
 
-TABULAR_SOURCE_TYPES = [CSV_SOURCE_TYPE, TSV_SOURCE_TYPE, EXCEL_SOURCE_TYPE, PARQUET_SOURCE_TYPE, FEATHER_SOURCE_TYPE,
-                        ORC_SOURCE_TYPE, STATA_SOURCE_TYPE, SAS_SOURCE_TYPE, SPSS_SOURCE_TYPE]
-DATA_SOURCE_TYPES = [RDB_SOURCE_TYPE] + TABULAR_SOURCE_TYPES
+FILE_SOURCE_TYPES = [CSV_SOURCE_TYPE, TSV_SOURCE_TYPE, EXCEL_SOURCE_TYPE, PARQUET_SOURCE_TYPE, FEATHER_SOURCE_TYPE,
+                     ORC_SOURCE_TYPE, STATA_SOURCE_TYPE, SAS_SOURCE_TYPE, SPSS_SOURCE_TYPE, JSON_SOURCE_TYPE,
+                     XML_SOURCE_TYPE]
+DATA_SOURCE_TYPES = [RDB_SOURCE_TYPE] + FILE_SOURCE_TYPES
 
 
 ##############################################################################
@@ -88,6 +91,8 @@ OUTPUT_FORMAT_FILE_EXTENSION = {
 ###########################   R2RML SPECIFICATION   ##########################
 ##############################################################################
 
+R2RML_NAMESPACE = 'http://www.w3.org/ns/r2rml#'
+
 # classes
 R2RML_BASE_TABLE_OR_VIEW_CLASS = 'http://www.w3.org/ns/r2rml#BaseTableOrView'
 R2RML_GRAPH_MAP_CLASS = 'http://www.w3.org/ns/r2rml#GraphMap'
@@ -153,4 +158,8 @@ RML_REFERENCE = 'http://semweb.mmlab.be/ns/rml#reference'
 RML_REFERENCE_FORMULATION = 'http://semweb.mmlab.be/ns/rml#referenceFormulation'
 
 
+##############################################################################
+##################################   OTHER   #################################
+##############################################################################
+
 AUXILIAR_UNIQUE_REPLACING_STRING = 'zzyy_xxww\u200B'
