@@ -16,8 +16,8 @@ from falcon.uri import encode
 
 from .utils import *
 from .constants import *
-from .data_source.relational_source import get_sql_data
-from .data_source.tabular_source import get_table_data
+from .data_source.relational_database import get_sql_data
+from .data_source.data_file import get_file_data
 
 
 def _get_references_in_mapping_rule(mapping_rule, only_subject_map=False):
@@ -245,8 +245,8 @@ def _materialize_mapping_rule(mapping_rule, subject_maps_df, config):
 
             if mapping_rule['source_type'] == RDB_SOURCE_TYPE:
                 result_chunks = get_sql_data(config, mapping_rule, references)
-            elif mapping_rule['source_type'] in TABULAR_SOURCE_TYPES:
-                result_chunks = get_table_data(config, mapping_rule, references)
+            elif mapping_rule['source_type'] in FILE_SOURCE_TYPES:
+                result_chunks = get_file_data(config, mapping_rule, references)
 
             for query_results_chunk_df in result_chunks:
                 query_results_chunk_df = dataframe_columns_to_str(query_results_chunk_df)
@@ -256,8 +256,8 @@ def _materialize_mapping_rule(mapping_rule, subject_maps_df, config):
 
                 if parent_triples_map_rule['source_type'] == RDB_SOURCE_TYPE:
                     parent_result_chunks = get_sql_data(config, parent_triples_map_rule, parent_references)
-                elif parent_triples_map_rule['source_type'] in TABULAR_SOURCE_TYPES:
-                    parent_result_chunks = get_table_data(config, parent_triples_map_rule, parent_references)
+                elif parent_triples_map_rule['source_type'] in FILE_SOURCE_TYPES:
+                    parent_result_chunks = get_file_data(config, parent_triples_map_rule, parent_references)
 
                 for parent_query_results_chunk_df in parent_result_chunks:
                     parent_query_results_chunk_df = dataframe_columns_to_str(parent_query_results_chunk_df)
@@ -267,19 +267,18 @@ def _materialize_mapping_rule(mapping_rule, subject_maps_df, config):
                     merged_query_results_chunk_df = _merge_results_chunks(query_results_chunk_df,
                                                                           parent_query_results_chunk_df, mapping_rule)
 
-                    triples.update(
-                        _materialize_join_mapping_rule_terms(merged_query_results_chunk_df, mapping_rule,
-                                                             parent_triples_map_rule))
+                    triples.update(_materialize_join_mapping_rule_terms(merged_query_results_chunk_df, mapping_rule,
+                                   parent_triples_map_rule))
 
     else:
         if mapping_rule['source_type'] in RDB_SOURCE_TYPE:
             result_chunks = get_sql_data(config, mapping_rule, references)
-        elif mapping_rule['source_type'] in TABULAR_SOURCE_TYPES:
-            result_chunks = get_table_data(config, mapping_rule, references)
+        elif mapping_rule['source_type'] in FILE_SOURCE_TYPES:
+            result_chunks = get_file_data(config, mapping_rule, references)
 
         for query_results_chunk_df in result_chunks:
             #query_results_chunk_df.replace(config.get_na_values(), np.NaN)
-            query_results_chunk_df.dropna(axis=0, how='any', inplace=True)
+            query_results_chunk_df.dropna(axis=0, how='any', inplace=True)  # this line should apply only in some cases
             query_results_chunk_df = dataframe_columns_to_str(query_results_chunk_df)
             triples.update(_materialize_mapping_rule_terms(query_results_chunk_df, mapping_rule, config))
 
